@@ -15,8 +15,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -122,11 +122,9 @@ html_button_init (HTMLButton *button,
 		  HTMLButtonType type)
 {
 	HTMLEmbedded *element;
-	HTMLObject *object;
 	GtkWidget  *widget;
 
 	element = HTML_EMBEDDED (button);
-	object = HTML_OBJECT (button);
 	widget = NULL;
 
 	html_embedded_init (element, HTML_EMBEDDED_CLASS (klass), parent, name, value);
