@@ -15,8 +15,8 @@
    
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef HTMLENGINE_EDIT_TEXT_H
@@ -27,4 +27,6 @@
 void               html_engine_capitalize_word                   (HTMLEngine       *e);
 void               html_engine_upcase_downcase_word              (HTMLEngine       *e,
 								  gboolean          up);
+void               html_engine_set_link                          (HTMLEngine       *e,
+								  const char       *complete_url);
 #endif
